﻿using Azure.Identity;
using Azure.ResourceManager.Resources;
using Azure.ResourceManager.Resources.Models;

using System;
using System.IO;
using System.Threading.Tasks;

namespace Deploy_ARM_Template
{
   class Program
   {
      static async Task Main(string[] args)
      {
         string subscriptionId = "<Your Subscription Id>";
         string templateFile = @"<Path to your Template file>";
         string parametersFile = @"<Path to the parameters file>";
         string resourceGroupName = "<Resource Group Name>";
         // Validate the files
         if (!File.Exists(templateFile))
         {
            Console.WriteLine($"The file {templateFile} do not exist");
            return;
         }
         if (!File.Exists(parametersFile))
         {
            Console.WriteLine($"The file {parametersFile} do not exist");
            return;

         }
         var credentials = new DefaultAzureCredential();

         var resourceClient = new ResourcesManagementClient(subscriptionId, credentials);
         var resourceGroups = resourceClient.ResourceGroups;
         // Validate the resource Group
         var rg = resourceGroups.Get(resourceGroupName);
         if (rg == null)
         {
            Console.WriteLine($"The Resource Group {resourceGroupName} is not accessible in the subscription");
            return;

         }
         // Generate a random deployment name
         string deploymentName = "dep" + DateTime.Now.ToFileTime().ToString();
         // Read the content of the Template File into a string
         string templateJson = File.ReadAllText(templateFile);
         // Get the Parameters from the JSON file
         ParametersObject parametersobj = System.Text.Json.JsonSerializer.Deserialize<ParametersObject>(File.ReadAllText(parametersFile));
         // Convert the name value pairs of the parameters into a JSON string
         string parametersJson = System.Text.Json.JsonSerializer.Serialize(parametersobj.parameters);
         var deployments = resourceClient.Deployments;
         var parameters = new Deployment
               (
                   new DeploymentProperties(DeploymentMode.Incremental)
                   {
                      Template = templateJson,
                      Parameters = parametersJson
                   }
                );
         var rawResult = await deployments.StartCreateOrUpdateAsync(resourceGroupName, deploymentName, parameters);
         await rawResult.WaitForCompletionAsync();
      }
   }

   /// <summary>
   /// This class represents the content of the parameters.json file, according to the schema at
   /// https://schema.management.azure.com/schemas/2015-01-01/deploymentParameters.json
   /// </summary>
   public class ParametersObject
   {
      public string schema { get; set; }
      public string contentVersion { get; set; }
      /// <summary>
      /// The parameters property is defined of object type, to receive any quantity and combination of parameters. 
      /// When serialized, the result string is the exact schema definition the <see cref="DeploymentProperties.Parameters"/> expect.
      /// </summary>
      public object parameters { get; set; }
   }


}
