﻿[CmdLetBinding()]
param
(
    [Parameter(Mandatory=$true,Position=0,HelpMessage="You must set the Resource Group" )]
        [string]$ResourceGroupName,
    [Parameter(Mandatory=$true,Position=1,HelpMessage="You must set the Storage Account" )]
        [string]$AccountName,
    [Parameter(Mandatory=$true,Position=2,HelpMessage="The Action is required")]
    [ValidateSet("Delete","TierToArchive","TierToCool")]
        [string]$BlobAction,
    [Parameter(Mandatory=$true,Position=3,HelpMessage="You must Define the days after modification Value" )]
        [int]$Days,
    [Parameter(Mandatory=$true,Position=4,HelpMessage="You must set the prefix filter" )]
        [string]$Prefix
)

Import-Module -Name Az 
#Connect to your Azure Account
Connect-AzAccount


#Create a new action object
$action = Add-AzStorageAccountManagementPolicyAction `
    -BaseBlobAction $BlobAction `
    -daysAfterModificationGreaterThan $Days

# Create a new filter object
$filter = New-AzStorageAccountManagementPolicyFilter `
    -PrefixMatch $Prefix

#Create a new rule object
$rule1 = New-AzStorageAccountManagementPolicyRule `
    -Name Test `
    -Action $action `
    -Filter $filter

#Set the policy
Set-AzStorageAccountManagementPolicy `
    -ResourceGroupName $ResourceGroupName `
    -StorageAccountName $AccountName `
    -Rule $rule1